==> antaresEditObject_0.4.0.tar.gz: antaresEditObject/README.md <==
<img src="man/figures/antares_simulator.png" align="right" width=250 />
<br/>

# antaresEditObject


> Edit an Antares study before running a simulation.

<!-- badges: start -->
[![Coverage Status](https://img.shields.io/codecov/c/github/rte-antares-rpackage/antaresEditObject/master.svg)](https://codecov.io/github/rte-antares-rpackage/antaresEditObject?branch=master)
[![version](http://www.r-pkg.org/badges/version/antaresEditObject)](https://CRAN.R-project.org/package=antaresEditObject)
[![cran checks](https://cranchecks.info/badges/worst/antaresEditObject)](https://cranchecks.info/pkgs/antaresEditObject)
[![Lifecycle: stable](https://img.shields.io/badge/lifecycle-stable-brightgreen.svg)](https://lifecycle.r-lib.org/articles/stages.html#stable)
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![cranlogs](http://cranlogs.r-pkg.org/badges/antaresEditObject)](https://CRAN.R-project.org/package=antaresEditObject)
[![R-CMD-check](https://github.com/rte-antares-rpackage/antaresEditObject/workflows/R-CMD-check/badge.svg)](https://github.com/rte-antares-rpackage/antaresEditObject/actions)
<!-- badges: end -->


## Installation

Install from CRAN:

```r
install.packages("antaresEditObject")
```

Or install dev version from GitHub:

```r
remotes::install_github("rte-antares-rpackage/antaresEditObject", build_vignettes = TRUE)
```


## Goal

This package allows to edit an Antares study. Methods are provided to create
(and remove) areas, links between them, thermal clusters and binding
constraints. These steps may be useful before running an Antares simulation.

See website for more documentation: https://rte-antares-rpackage.github.io/antaresEditObject/


## Usage

Usage of the package is detailed in the vignette: `vignette("antaresEditObject")`.

==> antaresEditObject_0.5.1.tar.gz: antaresEditObject/README.md <==
<img src="man/figures/antares_simulator.png" align="right" width=250 />
<br/>

# antaresEditObject


> Edit an Antares study before running a simulation.

<!-- badges: start -->
[![version](http://www.r-pkg.org/badges/version/antaresEditObject)](https://CRAN.R-project.org/package=antaresEditObject)
[![cran checks](https://cranchecks.info/badges/worst/antaresEditObject)](https://cranchecks.info/pkgs/antaresEditObject)
[![Lifecycle: stable](https://img.shields.io/badge/lifecycle-stable-brightgreen.svg)](https://lifecycle.r-lib.org/articles/stages.html#stable)
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![cranlogs](http://cranlogs.r-pkg.org/badges/antaresEditObject)](https://CRAN.R-project.org/package=antaresEditObject)
[![R-CMD-check](https://github.com/rte-antares-rpackage/antaresEditObject/workflows/R-CMD-check/badge.svg)](https://github.com/rte-antares-rpackage/antaresEditObject/actions)
[![Codecov test coverage](https://codecov.io/gh/rte-antares-rpackage/antaresEditObject/branch/master/graph/badge.svg)](https://app.codecov.io/gh/rte-antares-rpackage/antaresEditObject?branch=master)
<!-- badges: end -->


## Installation

Install from CRAN:

```r
install.packages("antaresEditObject")
```

Or install dev version from GitHub:

```r
remotes::install_github("rte-antares-rpackage/antaresEditObject", build_vignettes = TRUE)
```


## Goal

This package allows to edit an Antares study. Methods are provided to create
(and remove) areas, links between them, thermal clusters and binding
constraints. These steps may be useful before running an Antares simulation.

See website for more documentation: https://rte-antares-rpackage.github.io/antaresEditObject/


## Usage

Usage of the package is detailed in the vignette: `vignette("antaresEditObject")`.
